@@ -8,4 +8,4 @@ def generate_template(directory: str, data: dict):
         for key in data:
             snakypy.file.create(data[key], join(directory, key), force=True)
     except Exception:
-        raise Exception('There was an error creating the template.')
+        raise Exception("There was an error creating the template.")
